% Conway's Game of Life

num_iter = 9; % number of time steps

N = 8; % grid size
board = zeros(N);

init = 1; % 1 for glider, 2 for beacon

% initial pattern: glider
if (init == 1) 
  board(1,1) = 1;
  board(2,2) = 1;
  board(2,3) = 1;
  board(3,1) = 1;
  board(3,2) = 1;
end

% initial pattern: beacon
if (init == 2)
  board(3,3) = 1;
  board(3,4) = 1;
  board(4,3) = 1;
  board(4,4) = 1;
  board(5,5) = 1;
  board(5,6) = 1;
  board(6,5) = 1;
  board(6,6) = 1;
end

plotBoard (board);

for n=1:num_iter

  old_board = board;

  for rowId=1:N
    for colId=1:N

      count_live_neighbors = 0;
      for k=-1:+1
        for l=-1:+1

          if (k==0 && l==0)
            continue
          end

          s1 = rowId+k;
          s2 = colId+l;
          s1 = periodic(s1, N);
          s2 = periodic(s2, N);
          if (old_board(s1, s2) == 1)
            count_live_neighbors = count_live_neighbors+1;
          end

        end
      end

      info1 = ['For position: (', num2str(rowId)', ', ',num2str(colId), ...
               '), Number of neighbors alive: ', ...
               num2str(count_live_neighbors)'];

      % game rules
      if (old_board(rowId, colId) == 1)

        info2 = ['Old state: ', num2str(old_board(rowId, colId))];

        % dies from under- or over-population
        if (count_live_neighbors < 2 || count_live_neighbors > 3)
          board(rowId, colId) = 0;
        end

        info3 = ['New state: ', num2str(board(rowId, colId))];
      elseif (old_board(rowId, colId) == 0)
        if (count_live_neighbors == 3) % reproduction
          board(rowId, colId) = 1;
        end
      end

      %display(info1)
      %display(info2)
      %display(info3)

    end
  end
  %board
  plotBoard (board);
end

% periodic boundary
function s = periodic(r, N)

  if (r <= 0)
    s = N+r;
  elseif (r > N)    
    s = r-N;
  else
    s = r;
  end

end
