% Example of Runge with equidistant nodes

% interval boundaries
a = -1;
b = +1;

% number of nodes
N = [4,6,8,20];

% plot cosmetics
line = {'b-','r-','g-','m-','k-'};
leg  = {'f(x)','p_{3}(x)','p_{5}(x)','p_{7}(x)','p_{19}(x)'};
clf();
title('Example of Runge (equidistant nodes)');
hold on;

% plot Runge function
xx = linspace(a,b,200);
yy = 1./(25.*xx.^2 + 1.);
plot(xx,yy,line{1},'LineWidth',2);

% interpolate for different number of nodes
for i=1:length(N)
  % equidistant nodes
  x = linspace(a,b,N(i));
  % evaluate Runge function
  y = 1./(25.*x.^2 + 1.);
  % compute interpolation polynomial
  p = polyfit(x,y,N(i)-1);
  % evaluate
  yy = polyval(p,xx);
  % plot
  plot(xx,yy,line{i+1},'LineWidth',2)
end

% more cosmetics
box on;
legend(leg);

% hold off
hold off;

% save figure
print('-f1','-painters','-depsc2','runge_equi.eps'); % EPS format
print('-f1','-dpng','runge_equi.png'); % PNG format
